-- 
-- Turntable animation script
--

--local version = "0.1"			-- Initial version by Thomas and Roeland
--local version = "0.2"			-- Added spiral function and seperated functions into
					-- required files. Added tooltips to buttons. -Grimm
local version = "0.3"			-- Added shutter time slide and script exit button. -Grimm
					
-- load Octane ui elements
ui = require 'turntableG_files/uiG'

-- load the gui
require "turntableG_files/turntableG_gui"

-- load the animation functions
require "turntableG_files/turntableG_anim"

-- window that holds all components
local turntableWindow = octane.gui.create
{ 
    type     = octane.gui.componentType.WINDOW,
    text     = "Turntable Animation V"..version,
    children = { layoutGrp },
    width    = layoutGrp:getProperties().width,
    height   = layoutGrp:getProperties().height,
}

-- callback handling the GUI elements
local function guiCallback(component, event)
    if component == durationSlider then 
        -- if the duration of the animation changes, update the #frames
        local frames = math.ceil(durationSlider:getProperties().value * frameRateSlider:getProperties().value)
        frameSlider:updateProperties{ value = frames }
    elseif component == frameRateSlider then 
        -- if the frame rate changes, update the #frames
        local frames = math.ceil(durationSlider:getProperties().value * frameRateSlider:getProperties().value)
        frameSlider:updateProperties{ value = frames }
    elseif component == frameSlider then 
        -- if the #frames changes, update the duration of the animation
        local duration = frameSlider:getProperties().value / frameRateSlider:getProperties().value
        durationSlider:updateProperties{ value = duration }
    elseif component == fileChooseButton then 
        -- choose an output file
        print("hello from file choose")
        local ret = octane.gui.showDialog
        {
            type      = octane.gui.dialogType.FILE_DIALOG,
            title     = "Choose the output file",
            wildcards = "*.png",
            save      = true,
        }
        -- if a file is chosen
        if ret.result ~= "" then
            renderButton:updateProperties{ enable = true } 
            fileEditor:updateProperties{ text = ret.result }
            OUT_PATH = ret.result
        else
            renderButton:updateProperties{ enable = false } 
            fileEditor:updateProperties{ text = "" }
            OUT_PATH = nil
        end
    elseif component == renderButton then 
        startRender(SCENE_GRAPH, RT_NODE, CAM_NODE, OUT_PATH)

    elseif component == stopButton then
        cancelRender()

    elseif component == exitButton then
        cancelRender()
        turntableWindow:closeWindow()

    elseif component == turntableWindow then
        -- when the window closes, cancel rendering
        if event == octane.gui.eventType.WINDOW_CLOSE then
            cancelRender()
        end
    end
end
-- callback handling the GUI elements
--local function guiCallback(component, event)
--    if component == degSlider        then print("hello from degSlider")        end
--    if component == offsetSlider     then print("hello from offsetSlider")     end
--    if component == targetSlider     then print("hello from targetSlider")     end
--    if component == samplesSlider    then print("hello from samplesSlider")    end
--end

-- global variable that holds the output path
OUT_PATH = nil

-- Get the render target and camera in global variables
SCENE_GRAPH, RT_NODE, CAM_NODE = getSceneCopy()

-- initialize the UI
initGui(CAM_NODE)

-- hookup the callback with all the GUI elements
durationSlider:updateProperties   { callback = guiCallback }
frameRateSlider:updateProperties  { callback = guiCallback }
frameSlider:updateProperties      { callback = guiCallback }
fileChooseButton:updateProperties { callback = guiCallback }
renderButton:updateProperties     { callback = guiCallback }
stopButton:updateProperties       { callback = guiCallback }
exitButton:updateProperties       { callback = guiCallback }
turntableWindow:updateProperties  { callback = guiCallback }

-- degSlider:updateProperties        { callback = guiCallback }
-- offsetSlider:updateProperties     { callback = guiCallback }
-- targetSlider:updateProperties     { callback = guiCallback }
-- samplesSlider:updateProperties    { callback = guiCallback }

-- the script will block here until the window closes
turntableWindow:showWindow()
