-- 
-- Turntable gui script
--

-- lets create a bunch of labels and sliders
degLbl       = ui.createLabel("Degrees")
offsetLbl    = ui.createLabel("Start Angle")
targetLbl    = ui.createLabel("Target Offset")
durationLbl  = ui.createLabel("Duration")
frameRateLbl = ui.createLabel("Framerate")
frameLbl     = ui.createLabel("Frames")
samplesLbl   = ui.createLabel("Samples/px")
spiralLbl    = ui.createLabel("Spiral In/Out")
shutterLbl   = ui.createLabel("Shutter Time")

degSlider       = ui.createSlider("degree", 360, -360 , 360, 1, 400, 20)
offsetSlider    = ui.createSlider("offset", 0  , -180 , 180, 1, 400, 20)
targetSlider    = ui.createSlider("target", 10 , 0.001, 100, 0.001, 400, 20)
durationSlider  = ui.createSlider("duration", 10 , 1 , 3600  , 1, 400, 20)
frameRateSlider = ui.createSlider("rate", 25 , 10, 120   , 1, 400, 20)
frameSlider     = ui.createSlider("frames", 250, 10, 432000, 1, 400, 20)
samplesSlider   = ui.createSlider("samples", 400, 1 , 16000, 1, 400, 20)
spiralSlider    = ui.createSlider("spiral", 0, -20 , 20, 0.01, 400, 20)
shutterSlider   = ui.createSlider("shutter", 0, 0, 1, 0.001, 400, 20)

-- create a button to show a file chooser
fileChooseButton = ui.createButton("output", "Output...", 80, 20, "Choose a file name for the animation")

-- create an editor that will show the chosen file path
fileEditor = octane.gui.create
{
    type    = octane.gui.componentType.TEXT_EDITOR,
    text    = "",
    x       = 20,
    width   = 400,
    height  = 20,
    enable  = false,    
}

-- manual layouting is tedious so let's add all our stuff into groups.
-- camera movement group children
camera_children = 
    {
        degLbl           , degSlider       ,
        offsetLbl        , offsetSlider    ,
        targetLbl        , targetSlider    ,
        spiralLbl        , spiralSlider    ,
        shutterLbl       , shutterSlider   ,
    }

-- render group children
render_children = 
    {
        durationLbl      , durationSlider  ,
        frameRateLbl     , frameRateSlider ,
        frameLbl         , frameSlider     ,
        samplesLbl       , samplesSlider   ,
    }

output_children =
    {
        fileChooseButton, fileEditor,
    }

cameraGrp = ui.createGroup("camera_group", camera_children,true, 5, 2, nil, nil, "Camera Movement", { 2 }, { 5 })
renderGrp = ui.createGroup("render_group", render_children,true, 4, 2, nil, nil, "Render Settings", { 2 }, { 5 })

-- for layouting the button and the editor we use a group
fileGrp = ui.createGroup("output_group", output_children, true, 1, 2, nil, nil, "Output", { 2 }, { 5 })

-- progress bar 

-- eye candy, a progress bar
progressBar = octane.gui.create
{
    type   = octane.gui.componentType.PROGRESS_BAR,
    text   = "render progress",
    width  = fileGrp:getProperties().width * 0.8, -- as wide as the group above
    height = 20,
}

-- for layouting the progress bar
progressGrp = ui.createGroup("progress", { progressBar }, false, 1, 1, nil, nil, "", { 10 }, nil, true)

-- render & stop buttons

renderButton = ui.createButton("render", "Render", 80, 20, "Start the animation render")
stopButton = ui.createButton("stop", "Stop Render", 80, 20, "Stop the render")
exitButton = ui.createButton("exit", "Exit Script", 80, 20, "Stop the script")

buttonGrp = ui.createGroup("button", { renderButton, stopButton, exitButton }, false, 1, 3, nil, nil, "", { 5}, nil)

-- group that layouts the other groups
layout_children = 
    { 
        cameraGrp,
        renderGrp,
        fileGrp, 
        progressGrp,
        buttonGrp
    }

layoutGrp = ui.createGroup("layout", layout_children, false, 5, 1, nil, nil, "", { 2 }, nil, true)

-- helper to pop-up an error dialog and optionally halts the script
function showError(text, halt)
    octane.gui.showDialog
    {
        type  = octane.gui.dialogType.ERROR_DIALOG,
        title = "Turntable Animation Error",
        text  = text,
    }
    if halt then error("ERROR: "..text) end
end

